

#### Forward simulation of genetic drift for a biallelic locus, with constant population size, on a diploid organism ####

## PARAMETERS (the only values to change for simulations)
nbsim=200	# number of simulations (number of populations simulated)
nbgen=1000	# generation number
n=1000	# population size
p0 = 0.5	# initial frequency
freq=list()	# replicates of allele frequencies over generations

## SIMULATIONS WITH A BINOMIAL LAW
for (i in c(1:nbsim)){
	freq[[i]]=prob=p0
	for (j in c(0:nbgen)){
		all=rbinom(1, n, prob)
		prob=all/n
		freq[[i]][j+1]=prob
		}
	}

## SUMMARY STATISTICS CALCULATED FROM THE DATA
mat = matrix(unlist(freq),nr=nbsim,byrow=T) # matrix (row=simulation, column=allelic frequency each generation)
mean.freq = apply(mat,2,mean);mean.freq	# E(p_t) each generation 
var.freq  = apply(mat,2,var);var.freq	# Var(p_t) each generation 
het.freq =  2*mat*(1-mat)
het =  apply(het.freq,2,mean);het
inb  = var.freq/(p0*(1-p0));inb		# inbreeding coefficient each generation (f_t)

## GRAPHES WITH ALLELE FREQUENCY AND PARAMETERS TRAJECTORIES
plot(seq(0,nbgen,1),freq[[i]], ylim=c(0,1),xlab="generation number",ylab="allele frequency", type="l",main="valeurs calcules des paramtres")
for (i in c(1:nbsim)){
lines(seq(0,nbgen,1),freq[[i]], ylim=c(0,1))
}
lines(seq(0,nbgen,1),mean.freq, col="red",pch=16,lwd=2,lty=1)
lines(seq(0,nbgen,1),mean.freq+var.freq, col="red",lwd=2,lty=3)
lines(seq(0,nbgen,1),mean.freq-var.freq, col="red",lwd=2,lty=3)
lines(seq(0,nbgen,1),het, col="green",lwd=2,lty=1)
lines(seq(0,nbgen,1),inb, col="purple",lwd=2,lty=1)
legend("topleft",c("frquence moyenne (+ variance)", "htrozygotie", "coeff de consanguinit"),col = c("red","green","purple"),text.col = "black", lwd = c(2,2,2),merge = TRUE, bg = 'gray90',cex = 0.7,ncol=1)

## HETEROZYGOTIE FINALE (moyenne sur l'ensemble des ralisations)
het[nbgen]

## COEFFICIENT DE CONSANGUINITE FINAL  (moyenne sur l'ensemble des ralisations)
inb[nbgen]





